import * as cdk from '@aws-cdk/core';
/**
 * A resource provider for Aqua Enterprise KubeEnforcer.
 *
 * @schema CfnKubeenforcerProps
 */
export interface CfnKubeenforcerProps {
    /**
     * EKS cluster name.
     *
     * @schema CfnKubeenforcerProps#ClusterID
     */
    readonly clusterId?: string;
    /**
     * Secrets Manager ARN for kubeconfig file.
     *
     * @schema CfnKubeenforcerProps#KubeConfig
     */
    readonly kubeConfig?: string;
    /**
     * IAM to use with EKS cluster authentication, if not resource execution role will be used.
     *
     * @schema CfnKubeenforcerProps#RoleArn
     */
    readonly roleArn?: string;
    /**
     * Namespace to use with helm.
     *
     * Created if doesn't exist and default will be used if not provided
     *
     * @schema CfnKubeenforcerProps#Namespace
     */
    readonly namespace?: string;
    /**
     * Name for the helm release.
     *
     * @schema CfnKubeenforcerProps#Name
     */
    readonly name?: string;
    /**
     * Custom Values can optionally be specified.
     *
     * @schema CfnKubeenforcerProps#Values
     */
    readonly values?: any;
    /**
     * String representation of a values.yaml file.
     *
     * @schema CfnKubeenforcerProps#ValueYaml
     */
    readonly valueYaml?: string;
    /**
     * Version can be specified, if not latest will be used.
     *
     * @schema CfnKubeenforcerProps#Version
     */
    readonly version?: string;
    /**
     * Custom Value Yaml file can optionally be specified.
     *
     * @schema CfnKubeenforcerProps#ValueOverrideURL
     */
    readonly valueOverrideUrl?: string;
    /**
     * Timeout for resource provider.
     *
     * Default 60 mins
     *
     * @schema CfnKubeenforcerProps#TimeOut
     */
    readonly timeOut?: number;
    /**
     * For network connectivity to Cluster inside VPC.
     *
     * @schema CfnKubeenforcerProps#VPCConfiguration
     */
    readonly vpcConfiguration?: CfnKubeenforcerPropsVpcConfiguration;
}
/**
 * Converts an object of type 'CfnKubeenforcerProps' to JSON representation.
 */
export declare function toJson_CfnKubeenforcerProps(obj: CfnKubeenforcerProps | undefined): Record<string, any> | undefined;
/**
 * For network connectivity to Cluster inside VPC.
 *
 * @schema CfnKubeenforcerPropsVpcConfiguration
 */
export interface CfnKubeenforcerPropsVpcConfiguration {
    /**
     * Specify one or more security groups.
     *
     * @schema CfnKubeenforcerPropsVpcConfiguration#SecurityGroupIds
     */
    readonly securityGroupIds?: string[];
    /**
     * Specify one or more subnets.
     *
     * @schema CfnKubeenforcerPropsVpcConfiguration#SubnetIds
     */
    readonly subnetIds?: string[];
}
/**
 * Converts an object of type 'CfnKubeenforcerPropsVpcConfiguration' to JSON representation.
 */
export declare function toJson_CfnKubeenforcerPropsVpcConfiguration(obj: CfnKubeenforcerPropsVpcConfiguration | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Aqua::Enterprise::KubeEnforcer`.
 *
 * @external
 * @cloudformationResource Aqua::Enterprise::KubeEnforcer
 * @link https://github.com/aquasecurity/aqua-helm.git
 */
export declare class CfnKubeenforcer extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "Aqua::Enterprise::KubeEnforcer";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnKubeenforcerProps;
    /**
     * Attribute `Aqua::Enterprise::KubeEnforcer.ID`.
     *
     * @external
     * @link https://github.com/aquasecurity/aqua-helm.git
     */
    readonly attrId: string;
    /**
     * Create a new `Aqua::Enterprise::KubeEnforcer`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnKubeenforcerProps);
}
